Index: uspace/lib/usbdev/include/usb/dev/pipes.h
===================================================================
--- uspace/lib/usbdev/include/usb/dev/pipes.h	(revision 70452dd41310ff17f35dcb915b66bab0d5fd7c5f)
+++ uspace/lib/usbdev/include/usb/dev/pipes.h	(revision 1affcdf3220abde47fe1219335c44e6763d27fd6)
@@ -43,4 +43,5 @@
 #include <ddf/driver.h>
 #include <fibril_synch.h>
+#include <async.h>
 
 /** Abstraction of a physical connection to the device.
@@ -62,6 +63,6 @@
  *
  * Locking order: if you want to lock both mutexes
  * (@c guard and @c hc_phone_mutex), lock @c guard first.
  * It is not necessary to lock @c guard if you want to lock @c hc_phone_mutex
  * only.
  */
@@ -85,15 +86,15 @@
 	size_t max_packet_size;
 
 	/** Phone to the host controller.
 	 * Negative when no session is active.
 	 * It is an error to access this member without @c hc_phone_mutex
 	 * being locked.
 	 * If call over the phone is to be made, it must be preceeded by
 	 * call to pipe_add_ref() [internal libusb function].
 	 */
-	int hc_phone;
+	async_sess_t *hc_sess;
 
-	/** Guard for serialization of requests over the phone. */
-	fibril_mutex_t hc_phone_mutex;
+	/** Guard for serialization of requests over the session. */
+	fibril_mutex_t hc_sess_mutex;
 
 	/** Number of active transfers over the pipe. */
@@ -62,6 +63,6 @@
  *
  * Locking order: if you want to lock both mutexes
- * (@c guard and @c hc_phone_mutex), lock @c guard first.
- * It is not necessary to lock @c guard if you want to lock @c hc_phone_mutex
+ * (@c guard and @c hc_sess_mutex), lock @c guard first.
+ * It is not necessary to lock @c guard if you want to lock @c hc_sess_mutex
  * only.
  */
@@ -85,15 +86,15 @@
 	size_t max_packet_size;
 
-	/** Phone to the host controller.
-	 * Negative when no session is active.
-	 * It is an error to access this member without @c hc_phone_mutex
+	/** Session to the host controller.
+	 * NULL when no session is active.
+	 * It is an error to access this member without @c hc_sess_mutex
 	 * being locked.
 	 * If call over the phone is to be made, it must be preceeded by
